## 0.10.0 - 2023-11-29

### Added

- [#994](https://github.com/edgarrmondragon/citric/issues/994) Experimental support for the new REST API
- [#1016](https://github.com/edgarrmondragon/citric/issues/1016) Support `DestSurveyID` parameter in RPC method `copy_survey`
- [#1026](https://github.com/edgarrmondragon/citric/issues/1026) Support `userActivationSettings` parameter in RPC method `activate_survey`

### Fixed

- [#1026](https://github.com/edgarrmondragon/citric/issues/1026) Update `types.YesNo` to include inherited (`I`) values

### Documentation

- [#1035](https://github.com/edgarrmondragon/citric/issues/1035) Document how to disable TLS certificate verification
